import { composeStories } from "@storybook/react";
import * as stories from "../../../stories/components/common/IOC/IOCTable.stories";

const { AfterAsync } = composeStories(stories);
const textColumns = ["IOC name", "Description", "Host", "Network"];
const columns = ["Status"].concat(textColumns);
const firstRowData = [
  "Alert 1 warnings1 errors !",
  "CCCE:MOCK1",
  "Some description",
  "vacs-accv-vm-ioc",
  "ChannelAccess-FEB"
];

describe("IOCTable", () => {
  context("Populated Table", () => {
    beforeEach(() => {
      cy.mount(<AfterAsync />);
    });

    it("Has the correct columns", () => {
      cy.findAllByRole("columnheader").each(($el, index) => {
        cy.wrap($el).contains(columns[index], { matchCase: false });
      });
    });

    it("Truncates all text content", () => {
      cy.findAllByRole("row")
        .eq(1) // first row is headers, so get next index
        .find(".MuiTypography-noWrap")
        .should("have.length", textColumns.length - 1);
    });

    it("Displays correct content in first row", () => {
      cy.findAllByRole("row")
        .eq(1) // first row is headers, so get next index
        .each(($el, index) => {
          if (index === 0) {
            const iconTitle = firstRowData[index];
            cy.wrap($el).findByRole("cell", { name: iconTitle });
          } else {
            cy.wrap($el)
              .find("p")
              .should(($el) => {
                const text = $el.text().trim().toLowerCase();
                const expected = firstRowData[index].trim().toLowerCase();
                cy.expect(text).to.equal(expected);
              });
          }
        });
    });
  });
});
